package ShipIt::Bundle;

use strict;
use warnings;


our $VERSION = '0.02';


1;


__END__



=head1 NAME

ShipIt::Bundle - install all ShipIt-related distributions

=head1 SYNOPSIS

    cpan ShipIt::Bundle

=head1 DESCRIPTION

This bundle contains L<ShipIt> and all related distributions.

=head1 CONTENTS

ShipIt::Step::ApplyYAMLChangeLogVersion

ShipIt::Step::CheckYAMLChangeLog

ShipIt::Step::DistClean

ShipIt::Step::Jaiku

ShipIt::Step::Manifest

ShipIt::Step::Twitter

=head1 TAGS

If you talk about this module in blogs, on del.icio.us or anywhere else,
please use the C<shipitbundle> tag.

=head1 VERSION 
                   
This document describes version 0.02 of L<ShipIt::Bundle>.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests to
C<<bug-shipit-bundle@rt.cpan.org>>, or through the web interface at
L<http://rt.cpan.org>.

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.

=head1 AUTHOR

Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>

=head1 COPYRIGHT AND LICENSE

Copyright 2007 by Marcel GrE<uuml>nauer

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.


=cut

